mailr15113 - /branches/frame_order_testing/generic_fns/pymol_control.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on December 29, 2011 - 16:14:
Author: bugman
Date: Thu Dec 29 16:14:26 2011
New Revision: 15113

URL: http://svn.gna.org/viewcvs/relax?rev=15113&view=rev
Log:
Updated the pymol.cone_pdb() user function for the change to the cone PDB 
file.


Modified:
    branches/frame_order_testing/generic_fns/pymol_control.py

Modified: branches/frame_order_testing/generic_fns/pymol_control.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/frame_order_testing/generic_fns/pymol_control.py?rev=15113&r1=15112&r2=15113&view=diff
==============================================================================
--- branches/frame_order_testing/generic_fns/pymol_control.py (original)
+++ branches/frame_order_testing/generic_fns/pymol_control.py Thu Dec 29 
16:14:26 2011
@@ -253,8 +253,8 @@
     # The cone axes.
     ################
 
-    # Select the AVE, XAX, YAX, ZAX, and SIM residues.
-    pymol_obj.exec_cmd("select (resn AVE,XAX,YAX,ZAX,SIM)")
+    # Select the AVE, AXE, and SIM residues.
+    pymol_obj.exec_cmd("select (resn AVE,AXE,SIM)")
 
     # Show the vector as a stick.
     pymol_obj.exec_cmd("show stick, 'sele'")
@@ -263,7 +263,7 @@
     pymol_obj.exec_cmd("color cyan, 'sele'")
 
     # Select the atom used for labelling.
-    pymol_obj.exec_cmd("select (resn AVE,XAX,YAX,ZAX,SIM and symbol N)")
+    pymol_obj.exec_cmd("select (resn AVE,AXE,SIM and symbol N)")
 
     # Hide the atom.
     pymol_obj.exec_cmd("hide ('sele')")




Related Messages


Powered by MHonArc, Updated Thu Dec 29 16:40:02 2011